==> haskell-json-0.9.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json
version: 0.9.1
id: json-0.9.1-G9lxq5WdrzUDT7HRdlHQ5I
key: json-0.9.1-G9lxq5WdrzUDT7HRdlHQ5I
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
exposed-modules:
    Text.JSON Text.JSON.Types Text.JSON.String Text.JSON.ReadP
    Text.JSON.Generic Text.JSON.Pretty
abi: 1859f93ba3da937e171206feb082a7ad
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/json-0.9.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/json-0.9.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/json-0.9.1
hs-libraries: HSjson-0.9.1-G9lxq5WdrzUDT7HRdlHQ5I
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pretty-1.1.3.3
    syb-0.6-IcoSwlPi2Nx4zSqMmorFPS text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-json/html/json.haddock
haddock-html: /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-0.9.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json
version: 0.9.1
id: json-0.9.1-C2FDZAxuh5hCIxQmYtJQ5P
key: json-0.9.1-C2FDZAxuh5hCIxQmYtJQ5P
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
exposed-modules:
    Text.JSON Text.JSON.Types Text.JSON.String Text.JSON.ReadP
    Text.JSON.Generic Text.JSON.Pretty
abi: 574a624be118f0407f38b9a4b4ad7c94
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/json-0.9.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/json-0.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/json-0.9.1
hs-libraries: HSjson-0.9.1-C2FDZAxuh5hCIxQmYtJQ5P
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pretty-1.1.3.3
    syb-0.7-4OKdCpwGutyB1rNRmoa0ya text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-json/html/json.haddock
haddock-html: /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
